@@ -46,7 +46,11 @@
 
 /* Alignment */
 #if defined(__GNUC__)
+#ifdef WIN32
+#define FAME_ALIGNMENT 16
+#else
 #define FAME_ALIGNMENT 32
+#endif
 #define FAME_ALIGNED __attribute__ ((__aligned__(FAME_ALIGNMENT)))
 #else
 #define FAME_ALIGNED
@@ -62,6 +66,13 @@
       fprintf(stderr, "Error: " format, ##args)
 #define FAME_FATAL(format, args...) \
       { fprintf(stderr, "Fatal: " format, ##args); exit(-1); }
+#else /* not __GNUC__ */
+/* No vararg macros */
+int FAME_INFO(const char *format, ...);
+int FAME_WARNING(const char *format, ...);
+int FAME_ERROR(const char *format, ...);
+int FAME_FATAL(const char *format, ...);
+
 #endif
 
 #ifndef fame_min
@@ -79,7 +90,7 @@
 #define FAME_OVERLOADED(x) super_ ## x
 
 typedef struct _fame_yuv_t_ {
-  unsigned int w, h;
+  unsigned int w, h, p;
   unsigned char *y;
   unsigned char *u;
   unsigned char *v;
@@ -197,7 +208,7 @@ struct _fame_parameters_t_ {
   25,                                   /* 25 frames/second */               \
   1,                                    /* /1 */                             \
   100,                                  /* original shape */                 \
-  16,                                   /* 16 pixel wide search range */   \
+  0,                                    /* adaptative search range */        \
   1,                                    /* verbose mode */                   \
   "mpeg4",                              /* profile name */                   \
   0,                                    /* number of frames */               \
@@ -239,9 +250,9 @@ extern DECLSPEC void fame_end_frame(fame_context_t *context,
 extern DECLSPEC int fame_close(fame_context_t *context);
 
 /* DEPRECATED */
-extern DECLSPEC fame_frame_statistics_t *fame_encode_frame(fame_context_t *context,
-							   fame_yuv_t *yuv,
-							   unsigned char *mask);
+extern DECLSPEC int fame_encode_frame(fame_context_t *context,
+				      fame_yuv_t *yuv,
+				      unsigned char *mask);
 
 #ifdef __cplusplus
 }
