@@ -30,7 +30,6 @@ typedef struct _fame_syntax_t_ {
   void (* init)            (struct _fame_syntax_t_ *syntax,
 			    int mb_width,
 			    int mb_height,
-			    unsigned int search_range,
 			    unsigned char **intra_default_matrix,
 			    unsigned char **inter_default_matrix,
 			    unsigned char *intra_dc_y_scale_table,
@@ -54,7 +53,8 @@ typedef struct _fame_syntax_t_ {
 			    char frame_type,
 			    int frame_number,
 			    fame_box_t *box,
-			    int rounding_control);
+			    int rounding_control,
+			    int search_range);
   void (* start_slice)     (struct _fame_syntax_t_ *syntax,
 			    int vpos,
 			    int length,
@@ -67,12 +67,14 @@ typedef struct _fame_syntax_t_ {
 			    int k,
 			    fame_motion_vector_t *mv);
   void (* compute_chrominance_vectors)(struct _fame_syntax_t_ *syntax,
-				       struct _fame_motion_vector_t_ *vectors);
+				       struct _fame_motion_vector_t_ *vectors,
+				       unsigned char pattern);
   void (* write_intra_mb)  (struct _fame_syntax_t_ *syntax,
 			    int mb_x,
 			    int mb_y,
 			    short *blocks[6],
 			    unsigned char *bab,
+			    unsigned char *bab_map,
 			    fame_bab_t bab_type,
 			    unsigned char dquant,
 			    unsigned char pattern);
@@ -81,6 +83,7 @@ typedef struct _fame_syntax_t_ {
 			    int mb_y,
 			    short *blocks[6],
 			    unsigned char *bab,
+			    unsigned char *bab_map,
 			    fame_bab_t bab_type,
 			    unsigned char dquant,
 			    unsigned char pattern,
